@@ -2,12 +2,12 @@
 
 #include <RcppArmadillo.h>
 
-using namespace arma;
-using namespace Rcpp;
-
 inline double
-infeasibility(const mat gradient, const vec& lambda)
+infeasibility(const arma::mat gradient, const arma::vec& lambda)
 {
+  using namespace arma;
+
   vec infeas = cumsum(sort(abs(vectorise(gradient)), "descending") - lambda);
+
   return std::max(infeas.max(), 0.0);
 }
